@@ -1,6 +1,6 @@
 package MARC::Moose::Reader::File::Marcedit;
 # ABSTRACT: File reader for MARC::Moose record from Marcedit file (.mrk)
-$MARC::Moose::Reader::File::Marcedit::VERSION = '1.0.47';
+$MARC::Moose::Reader::File::Marcedit::VERSION = '1.0.48';
 use Moose;
 use Modern::Perl;
 use MARC::Moose::Record;
@@ -27,6 +27,20 @@ sub read {
     return if eof($fh);
 
     my @lines;
+
+    # Next record
+    my $found = 0;
+    while (<$fh>) {
+        $found = $_ =~ /^=LDR/;
+        if ($found) {
+            s/\n$//;
+            s/\r$//;
+            push @lines, $_;
+            last;
+        }
+    }
+    return unless $found;
+
     while (<$fh>) {
         s/\n$//;
         s/\r$//;
@@ -54,7 +68,7 @@ MARC::Moose::Reader::File::Marcedit - File reader for MARC::Moose record from Ma
 
 =head1 VERSION
 
-version 1.0.47
+version 1.0.48
 
 =head1 AUTHOR
 
